@@ -7,3 +7,8 @@ from .display import *
 from .util import *
 from .experiment import *
 from .agent_markers import *
+from .graph import *
+from .capture import *
+from .visibility import *
+
+
