@@ -11,18 +11,14 @@ class Step(JsonObject):
                  time_stamp: float = 0.0,
                  agent_name: str = "",
                  frame: int = 0,
-                 coordinates: Coordinates = None,
                  location: Location = None,
                  rotation: float = 0.0,
                  data: str = ""):
         self.time_stamp = time_stamp
         self.agent_name = agent_name
         self.frame = frame
-        if coordinates is None:
-            coordinates = Coordinates(0, 0)
         if location is None:
-            location = Location(0,0)
-        self.coordinates = coordinates
+            location = Location(0, 0)
         self.location = location
         self.rotation = rotation
         self.data = data
@@ -66,7 +62,7 @@ class Trajectories(JsonList):
     def __init__(self, iterable=None):
         JsonList.__init__(self, iterable, list_type=Step)
 
-    def get_velocities(self) -> Velocities:
+    def get_velocities(self) -> {}:
         velocities = {}
         last_locations = {}
         last_time_stamp = {}
@@ -82,7 +78,7 @@ class Trajectories(JsonList):
             last_time_stamp[s.agent_name] = s.time_stamp
         return velocities
 
-    def get_filtered_velocities(self, complementary: float=None, outliers: float=None) -> Velocities:
+    def get_filtered_velocities(self, complementary: float=None, outliers: float=None) -> {}:
         avs = self.get_velocities()
         for agent_name in avs:
             if outliers:
@@ -113,17 +109,20 @@ class Trajectories(JsonList):
 
 
 class Episode(JsonObject):
-    def __init__(self, start_time: datetime = None, time_stamp: float = 0.0, end_time: datetime = None, trajectories: Trajectories = None):
+    def __init__(self, start_time: datetime = None, time_stamp: float = 0.0, end_time: datetime = None, trajectories: Trajectories = None, captures: JsonList = None):
         if not start_time:
             start_time = datetime.now()
         self.start_time = start_time
         self.time_stamp = time_stamp
-        if not self.end_time:
+        if not end_time:
             end_time = datetime.now()
         self.end_time = end_time
         if trajectories is None:
             trajectories = Trajectories()
         self.trajectories = trajectories
+        if captures is None:
+            captures = JsonList(list_type=int)
+        self.captures = captures
 
 
 class Episode_list(JsonList):
@@ -177,3 +176,9 @@ class Experiment(JsonObject):
                 step.location = Space.transform_to(step.location, src_space, dst_space)
         self.world_implementation_name = dst_space_name
 
+    def set_name(self, prefix: str = None, suffix: str = None):
+        self.name = self.start_time.strftime("%Y%m%d_%OH%M_") + self.subject_name + "_" + self.occlusions;
+        if prefix:
+            self.name = prefix + "_" + self.name
+        if suffix:
+            self.name = self.name + "_" + suffix
